/*
   ADC.CPP
*/

#include "ADC.h"

CADC :: CADC( LPCTSTR name  )
  {
   FVDSPCMD.CardNo=1;
   FVDSPCMD.ChannelNo=1;
   FVDSPCMD.Offset=0;
   HVDSP=CreateFile ( name, GENERIC_READ,
                      0,
                      (LPSECURITY_ATTRIBUTES)NULL, OPEN_EXISTING,
                      FILE_ATTRIBUTE_NORMAL, (HANDLE)NULL );
   if (HVDSP == (HANDLE) INVALID_HANDLE_VALUE)
      throw (char *)"Mistake at opening the device";
   GetCardAccount(&CardAccount);
   if (CardAccount) GetChannelAccount(&ChannelAccount);
   else ChannelAccount=0;
  }

CADC :: ~CADC ( void )
  {
   CloseHandle(HVDSP);
  }

int CADC :: ExecCommand( DWORD Command , long BytesSend, void * OutBuf )
  {
   BytesPost=0;
   if (!DeviceIoControl(HVDSP, Command, &FVDSPCMD, sizeof(_CMDSTRUCT), OutBuf,
       BytesSend, &BytesPost, (LPOVERLAPPED)NULL ))
     {
      return GetLastError();
     }
   return 0;
  }


int CADC :: SetCard ( int card )
  {
   FVDSPCMD.CardNo=card;
   return 0;
  }

int CADC :: SetChannel ( int channel )
  {
   FVDSPCMD.ChannelNo=channel;
   return 0;
  }

int CADC :: GetCurrentCard ( int *val )
  {
   *val=FVDSPCMD.CardNo;
   return 0;
  }

int CADC :: GetCurrentChannel ( int *val )
  {
   *val=FVDSPCMD.ChannelNo;
   return 0;
  }

// Teams of ADC ====================================================

int CADC :: GetBufSize ( int *val )
  {
   *val=0;
   return ExecCommand (cmGetBufSize,4,val);
  }

int CADC :: GetChWidth ( int *val )
  {
   *val=0;
   return ExecCommand(cmGetChWidth,2,val);
  }

int CADC :: GetLLD ( int *val )
  {
   *val=0;
   return ExecCommand(cmGetLLD,2,val);
  }

int CADC :: GetULD ( int *val )
  {
   *val=0;
   return ExecCommand(cmGetULD,2,val);
  }

int CADC :: GetMode ( int *val )
  {
   *val=0;
   return ExecCommand (cmGetMode,1,val);
  }

int CADC :: GetInten ( int *val )
  {
   *val=0;
   return ExecCommand (cmGetInten,4,val);
  }

int CADC :: GetRealTime ( int *val )
  {
   *val=0;
   return ExecCommand ( cmGetRealTime, 4, val);
  }

int CADC :: GetLiveTime ( int *val )
  {
   *val=0;
   return ExecCommand ( cmGetLiveTime, 4, val );
  }

int CADC :: GetPresetRealTime ( int *val )
  {
   *val=0;
   return ExecCommand ( cmGetPresetRealTime, 4, val );
  }

int CADC :: GetPresetLiveTime ( int *val )
  {
   *val=0;
   return ExecCommand ( cmGetPresetLiveTime, 4, val );
  }

int CADC :: SetRealTime ( int time )
  {
   return ExecCommand ( cmSetRealTime, 4, &time );
  }

int CADC :: SetLiveTime ( int time )
  {
   return ExecCommand ( cmSetLiveTime, 4, &time );
  }

int CADC :: SetPresetRealTime ( int time )
  {
   return ExecCommand ( cmSetPresetRealTime, 4, &time );
  }

int CADC :: SetPresetLiveTime ( int time )
  {
   return ExecCommand ( cmSetPresetLiveTime, 4, &time );
  }

int CADC :: SetBufSize ( int size )
  {
   return ExecCommand (cmSetBufSize,4,&size);
  }

int CADC :: SetChWidth ( int chw )
  {
   return ExecCommand (cmSetChWidth,2,&chw);
  }

int CADC :: SetLLD ( int lld )
  {
   return ExecCommand ( cmSetLLD, 2, &lld );
  }

int CADC :: SetULD ( int uld )
  {
   return ExecCommand ( cmSetULD, 2, &uld );
  }

int CADC :: SetMode ( int mode )
  {
   return ExecCommand ( cmSetMode, 1, &mode );
  }

int CADC :: LockCh ( void )
  {
   return ExecCommand ( cmLockCh, 0, NULL );
  }

int CADC :: UnLockCh ( void )
  {
   return ExecCommand ( cmUnLockCh, 0, NULL );
  }

int CADC :: GetCardAccount ( int *val )
  {
   *val=0;
   return ExecCommand ( cmGetCardAccount, 1, val );
  }

int CADC :: GetChannelAccount ( int *val )
  {
   *val=0;
   return ExecCommand ( cmGetChannelAccount, 1, val );
  }

int CADC :: GetVxdVer ( int *val )
  {
   *val=0;
   return ExecCommand ( cmGetVxdVer, 2, val );
  }

int CADC :: GetADCVer ( int *val )
  {
   *val=0;
   return ExecCommand ( cmGetADCVer, 4, val );
  }

int CADC :: GetStatus ( int *val )
  {
   *val=0;
   return ExecCommand ( cmGetStatus, 4, val );
  }

int CADC :: ClearBuf ( void )
  {
   return ExecCommand ( cmClearBuf, 0, NULL );
  }

int CADC :: RunChannel ( void )
  {
   return ExecCommand ( cmRunChannel, 0, NULL );
  }

int CADC :: StopChannel ( void )
  {
   return ExecCommand ( cmStopChannel, 0, NULL );
  }

int CADC :: WriteEPROM (void * p)
  {
   return ExecCommand (cmWriteEPROM,4,p);
  }

int CADC :: ReadEPROM (void *p)
  {
   return ExecCommand ( cmReadEPROM, 4, p );
  }

int CADC :: WriteBuf ( void * p, int size )
  {
   return ExecCommand ( cmWriteBuf, size, p );
  }

int CADC :: ReadBuf ( void * p, int size )
  {
   return ExecCommand ( cmReadBuf, size, p );
  }

//---------------------------------------------------------------------------
